@@ -135,7 +135,7 @@ SKIP: {
     }
     my $cmd = Test::Command->new(cmd => "fping --print-ttl ::1");
     $cmd->exit_is_num(0);
-    $cmd->stdout_like(qr{::1 is alive \(TTL unknown\)\n});
+    $cmd->stdout_like(qr{::1 is alive \(TTL \d+\)\n});
     $cmd->stderr_is_eq("");
 }
 
