@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-use Test::Command tests => 48;
+use Test::Command tests => 51;
 use Test::More;
 
 #  -n         show targets by name (-d is equivalent)
@@ -83,7 +83,7 @@ SKIP: {
     }
     my $cmd = Test::Command->new(cmd => "fping --print-tos ::1");
     $cmd->exit_is_num(0);
-    $cmd->stdout_like(qr{::1 is alive \(TOS unknown\)\n});
+    $cmd->stdout_like(qr{::1 is alive \(TOS \d+\)\n});
     $cmd->stderr_is_eq("");
 }
 
@@ -97,7 +97,10 @@ $cmd->stderr_like(qr{127\.0\.0\.1 : xmt/rcv/%loss = 3/3/0%, min/avg/max = \d\.\d
 }
 
 # fping -Q
-{
+SKIP: {
+if($^O eq 'darwin') {
+    skip 'On macOS, -Q tests are unreliable', 3;
+}
 my $cmd = Test::Command->new(cmd => "fping -Q 1 -p 400 -c 4 127.0.0.1");
 $cmd->exit_is_num(0);
 $cmd->stdout_is_eq("");
@@ -107,8 +110,25 @@ $cmd->stderr_like(qr{\[\d+:\d+:\d+\]
 });
 }
 
+# fping -Q (fractional time)
+SKIP: {
+if($^O eq 'darwin') {
+    skip 'On macOS, -Q tests are unreliable', 3;
+}
+my $cmd = Test::Command->new(cmd => "fping -Q0.5 -p 200 -c 4 127.0.0.1");
+$cmd->exit_is_num(0);
+$cmd->stdout_is_eq("");
+$cmd->stderr_like(qr{\[\d+:\d+:\d+\]
+127\.0\.0\.1 : xmt/rcv/%loss = 3/3/0%, min/avg/max = \d\.\d+/\d\.\d+/\d\.\d+
+127\.0\.0\.1 : xmt/rcv/%loss = 4/4/0%, min/avg/max = \d\.\d+/\d\.\d+/\d\.\d+
+});
+}
+
 # fping -Q (longer test to show two time stamps and reset statistics)
-{
+SKIP: {
+if($^O eq 'darwin') {
+    skip 'On macOS, -Q tests are unreliable', 3;
+}
 my $cmd = Test::Command->new(cmd => "fping -Q 1 -p 550 -c 5 127.0.0.1");
 $cmd->exit_is_num(0);
 $cmd->stdout_is_eq("");
@@ -120,22 +140,12 @@ $cmd->stderr_like(qr{\[\d+:\d+:\d+\]
 });
 }
 
-# fping -Q n ignores non-number characters after the number, except for keywords
-{
-my $cmd = Test::Command->new(cmd => "fping -Q 1whatever -p 550 -c 5 127.0.0.1");
-$cmd->exit_is_num(0);
-$cmd->stdout_is_eq("");
-$cmd->stderr_like(qr{\[\d+:\d+:\d+\]
-127\.0\.0\.1 : xmt/rcv/%loss = 2/2/0%, min/avg/max = \d\.\d+/\d\.\d+/\d\.\d+
-\[\d+:\d+:\d+\]
-127\.0\.0\.1 : xmt/rcv/%loss = 2/2/0%, min/avg/max = \d\.\d+/\d\.\d+/\d\.\d+
-127\.0\.0\.1 : xmt/rcv/%loss = 5/5/0%, min/avg/max = \d\.\d+/\d\.\d+/\d\.\d+
-});
-}
-
 # fping -Q n ignores unknown keywords
-{
-my $cmd = Test::Command->new(cmd => "fping -Q 1,not_a_keyword -p 550 -c 5 127.0.0.1");
+SKIP: {
+if($^O eq 'darwin') {
+    skip 'On macOS, -Q tests are unreliable', 3;
+}
+my $cmd = Test::Command->new(cmd => "fping -Q 0.5,not_a_keyword -p 300 -c 5 127.0.0.1");
 $cmd->exit_is_num(0);
 $cmd->stdout_is_eq("");
 $cmd->stderr_like(qr{\[\d+:\d+:\d+\]
@@ -147,8 +157,11 @@ $cmd->stderr_like(qr{\[\d+:\d+:\d+\]
 }
 
 # fping -Q n,cumulative
-{
-my $cmd = Test::Command->new(cmd => "fping -Q 1,cumulative -p 550 -c 5 127.0.0.1");
+SKIP: {
+if($^O eq 'darwin') {
+    skip 'On macOS, -Q tests are unreliable', 3;
+}
+my $cmd = Test::Command->new(cmd => "fping -Q 0.5,cumulative -p 300 -c 5 127.0.0.1");
 $cmd->exit_is_num(0);
 $cmd->stdout_is_eq("");
 $cmd->stderr_like(qr{\[\d+:\d+:\d+\]
@@ -160,28 +173,42 @@ $cmd->stderr_like(qr{\[\d+:\d+:\d+\]
 }
 
 # fping -Q -o
-{
-my $cmd = Test::Command->new(cmd => "fping -c4 -Q1 -p550 -o 8.8.8.7");
+SKIP: {
+if($^O eq 'darwin') {
+    skip 'On macOS, -Q tests are unreliable', 3;
+}
+my $cmd = Test::Command->new(cmd => "fping -c4 -Q0.5 -p300 -o 8.8.8.7");
 $cmd->exit_is_num(1);
 $cmd->stdout_is_eq("");
 $cmd->stderr_like(qr{\[\d+:\d+:\d+\]
-8\.8\.8\.7 : xmt/rcv/%loss = 1/0/100%, outage\(ms\) = 55\d
+8\.8\.8\.7 : xmt/rcv/%loss = 1/0/100%, outage\(ms\) = 30\d
 \[\d+:\d+:\d+\]
-8\.8\.8\.7 : xmt/rcv/%loss = 2/0/100%, outage\(ms\) = 110\d
-8\.8\.8\.7 : xmt/rcv/%loss = 4/0/100%, outage\(ms\) = 220\d
+8\.8\.8\.7 : xmt/rcv/%loss = 2/0/100%, outage\(ms\) = 60\d
+8\.8\.8\.7 : xmt/rcv/%loss = 4/0/100%, outage\(ms\) = 120\d
 });
 }
 
 # fping -Q n,cumulative -o
-{
-my $cmd = Test::Command->new(cmd => "fping -c4 -Q1,cumulative -p550 -o 8.8.8.7");
+SKIP: {
+if($^O eq 'darwin') {
+    skip 'On macOS, -Q tests are unreliable', 3;
+}
+my $cmd = Test::Command->new(cmd => "fping -c4 -Q0.5,cumulative -p300 -o 8.8.8.7");
 $cmd->exit_is_num(1);
 $cmd->stdout_is_eq("");
 $cmd->stderr_like(qr{\[\d+:\d+:\d+\]
-8\.8\.8\.7 : xmt/rcv/%loss = 1/0/100%, outage\(ms\) = 55\d
+8\.8\.8\.7 : xmt/rcv/%loss = 1/0/100%, outage\(ms\) = 30\d
 \[\d+:\d+:\d+\]
-8\.8\.8\.7 : xmt/rcv/%loss = 3/0/100%, outage\(ms\) = 165\d
-8\.8\.8\.7 : xmt/rcv/%loss = 4/0/100%, outage\(ms\) = 220\d
+8\.8\.8\.7 : xmt/rcv/%loss = 3/0/100%, outage\(ms\) = 90\d
+8\.8\.8\.7 : xmt/rcv/%loss = 4/0/100%, outage\(ms\) = 120\d
 });
 }
 
+
+# fping -O (hex)
+{
+my $cmd = Test::Command->new(cmd => "fping -O 0x20 --print-tos 127.0.0.1");
+$cmd->exit_is_num(0);
+$cmd->stdout_like(qr{127\.0\.0\.1 is alive \(TOS 32\)}); 
+$cmd->stderr_is_eq("");
+}
\ No newline at end of file
